==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/fr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gérer les paramètres Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Gérer Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Agrandir l&#39;image Largeur");
define('MANAGE_GALLERY_FULL_HEIGHT', "Agrandir l&#39;image Hauteur");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniature Largeur de l&#39;image");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Vignette Hauteur");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Conserver les proportions de Pouce");
define('MANAGE_GALLERY_SHOW_TITLES', "Afficher les titres");
define('MANAGE_GALLERY_DISABLE_SORT', "Désactiver Trier");
define('MANAGE_GALLERY_DELETE_IMAGE', "Supprimer l&#39;image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Enregistrer l&#39;ordre de tri");
define('MANAGE_GALLERY_PUBLISH_MSG', "Cliquez sur &quot;Update&quot; pour publier <br /> vos images téléchargées.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Toutes les images ont été redimensionnées et paramètres ont été enregistrés.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Il y avait une erreur de redimensionnement des images ou l&#39;enregistrement des paramètres.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Votre image (s) a été téléchargé.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Il y avait une erreur de télécharger votre image (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Le fichier que vous essayez de télécharger est pas une image.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Le fichier que vous essayez de télécharger est trop grand.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Le titre a été enregistré.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Etes-vous sûr de vouloir supprimer l&#39;image");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "L&#39;image a été supprimée.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Il y avait une erreur de supprimer l&#39;image.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Sauvegarde des paramètres et le redimensionnement des images, s&#39;il vous plaît patienter ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, s&#39;il vous plaît patienter ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L&#39;ordre de tri n&#39;a pas été enregistré. Voulez-vous enregistrer l&#39;ordre de tri?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L&#39;ordre de tri d&#39;image a été enregistrée.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Il y avait un enregistrement de l&#39;image tri erreur.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/fr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gérer les paramètres Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Gérer Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Agrandir l&#39;image Largeur");
define('MANAGE_GALLERY_FULL_HEIGHT', "Agrandir l&#39;image Hauteur");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniature Largeur de l&#39;image");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Vignette Hauteur");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Conserver les proportions de Pouce");
define('MANAGE_GALLERY_SHOW_TITLES', "Afficher les titres");
define('MANAGE_GALLERY_DISABLE_SORT', "Désactiver Trier");
define('MANAGE_GALLERY_DELETE_IMAGE', "Supprimer l&#39;image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Enregistrer l&#39;ordre de tri");
define('MANAGE_GALLERY_PUBLISH_MSG', "Cliquez sur &quot;Update&quot; pour publier <br /> vos images téléchargées.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Toutes les images ont été redimensionnées et paramètres ont été enregistrés.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Il y avait une erreur de redimensionnement des images ou l&#39;enregistrement des paramètres.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Votre image (s) a été téléchargé.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Il y avait une erreur de télécharger votre image (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Le fichier que vous essayez de télécharger est pas une image.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Le fichier que vous essayez de télécharger est trop grand.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Le titre a été enregistré.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Etes-vous sûr de vouloir supprimer l&#39;image");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "L&#39;image a été supprimée.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Il y avait une erreur de supprimer l&#39;image.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Sauvegarde des paramètres et le redimensionnement des images, s&#39;il vous plaît patienter ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, s&#39;il vous plaît patienter ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L&#39;ordre de tri n&#39;a pas été enregistré. Voulez-vous enregistrer l&#39;ordre de tri?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L&#39;ordre de tri d&#39;image a été enregistrée.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Il y avait un enregistrement de l&#39;image tri erreur.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Le fichier que vous essayez de télécharger est plus volumineux que les paramètres PHP &quot;upload_max_filesize&quot; ou &quot;post_max_size&quot;. Contactez votre administrateur système pour augmenter ces limites.");
?>
